```
@misc{
title={ROUGE: A Package for Automatic Evaluation of Summaries},
author={Chin-Yew Lin.}, year={2004},
DOI=""
}

@misc{
title={Bleu: a Method for Automatic Evaluation of Machine Translation},
author={Papineni et al.}, year={2002},
DOI=10.3115/1073083.1073135
}

@misc{
title={BERTScore: Evaluating Text Generation with BERT},
author={Zhang et al.}, year={2019},
DOI=https://doi.org/10.48550/arXiv.1904.09675
}

@misc{
title={On Faithfulness and Faithfulness in Abstractive Summarization},
author={Maynez* et al.}, year={2020},
DOI=https://doi.org/10.48550/arXiv.2005.00661
}

@misc{
title={Q^2: Evaluating Factual Consistency in Knowledge-Grounded Dialogues via Question Generation and Question Answering},
author={Honovich et al.}, year={2021},
DOI=https://doi.org/10.48550/arXiv.2104.08202
}

```
